package com.yijia.station.service;

import java.util.List;
import com.yijia.station.domain.StationDeviceManage;

/**
 * 油站设备管理Service接口
 * 
 * @author yijia
 * @date 2020-12-09
 */
public interface IStationDeviceManageService 
{
    /**
     * 查询油站设备管理
     * 
     * @param deviceId 油站设备管理ID
     * @return 油站设备管理
     */
    public StationDeviceManage selectStationDeviceManageById(Long deviceId);

    /**
     * 查询油站设备管理列表
     * 
     * @param stationDeviceManage 油站设备管理
     * @return 油站设备管理集合
     */
    public List<StationDeviceManage> selectStationDeviceManageList(StationDeviceManage stationDeviceManage);

    /**
     * 新增油站设备管理
     * 
     * @param stationDeviceManage 油站设备管理
     * @return 结果
     */
    public int insertStationDeviceManage(StationDeviceManage stationDeviceManage);

    /**
     * 修改油站设备管理
     * 
     * @param stationDeviceManage 油站设备管理
     * @return 结果
     */
    public int updateStationDeviceManage(StationDeviceManage stationDeviceManage);

    /**
     * 批量删除油站设备管理
     * 
     * @param deviceIds 需要删除的油站设备管理ID
     * @return 结果
     */
    public int deleteStationDeviceManageByIds(Long[] deviceIds);

    /**
     * 删除油站设备管理信息
     * 
     * @param deviceId 油站设备管理ID
     * @return 结果
     */
    public int deleteStationDeviceManageById(Long deviceId);
}
